#ifndef umFishLoad_h
#define umFishLoad_h
// -----------------------------------------------------------------------------
//
// umFish30Load.h                                         Ulrich Mller  29.5.02
//                                                        PCS1700 C++Builder 4.0
//
// Basisfunktionen fr die fischertechnik Interfaces (seriell und und parallel)
// Dynamisches Laden der umFish30.DLL
//
// -----------------------------------------------------------------------------

#include <windows.h>

typedef struct {
  HANDLE hCom;                 // --- PortHandle / Openflag ( = 0)
  DWORD PortID;                //     IO-Adresse bei LPT
  DWORD LPTDelay;              //     LPT Verzgerungsfaktor
  DWORD LPTAnalog;             //     LPT Analogfaktor
  DWORD ECount;                //     Anzahl E-Eingnge (8/16)
	DWORD FID;                   // --- MultiMediaTimer Handle
	DWORD PollInterval;          //     Pollinterval des MM-Timers
	DWORD AnalogScan;            //     Pollen auch der Analogeingnge (0/1)
	DWORD OutputStatus;          // --- akt. Status der M-Ausgnge
  DWORD MotorStatus;           //     Sollstatus der M-Ausgnge (00|01|10)
  DWORD SpeedStatus;           //     den M-Ausgngen zug. Geschwindigkeit
  DWORD ModeStatus;            //     den M-ausgngen zug. Mode
  DWORD intern;
	DWORD InputStatus;           //     Status der E-Eingnge
  DWORD Analogs[2];            //     Werte der A-Eingnge
	DWORD Counters[16];          //     Impulszhler an den E-Eingngen
} ftiDCB;

HINSTANCE umFishLib;

// --- umFish30 : Funktionsprototypen ------------------------------------------

typedef DWORD (__stdcall *TOpenInterface) (ftiDCB &Interface, LPCSTR ComName);
typedef DWORD (__stdcall *TCloseInterface) (ftiDCB &Interface);
typedef DWORD (__stdcall *TVersion) ();
typedef DWORD (__stdcall *TGetAnalogDirect) (ftiDCB &Interface, DWORD AnalogNr);
typedef BOOL  (__stdcall *TGetInput) (ftiDCB &Interface, DWORD InputNr);
typedef DWORD (__stdcall *TSetLamp) (ftiDCB &Interface, DWORD LampNr, DWORD OnOff);
typedef DWORD (__stdcall *TSetMotor) (ftiDCB &Interface,
        DWORD MotorNr, DWORD Direction);
typedef DWORD (__stdcall *TSetMotorEx) (ftiDCB &Interface,
        DWORD MotorNr, DWORD Direction, DWORD Speed);
typedef DWORD (__stdcall *TSetMotors) (ftiDCB &Interface, DWORD MotorStatus);
typedef DWORD (__stdcall *TSetMotorsEx) (ftiDCB &Interface, DWORD MotorStatus,
        DWORD SpeedStatus);
typedef DWORD (__stdcall *TRobMotors) (ftiDCB &Interface, DWORD MotorStatus,
        DWORD SpeedStatus, DWORD ModeStatus);
typedef DWORD (__stdcall *TRobMotor) (ftiDCB &Interface, DWORD MotorNr,
        DWORD Direction, DWORD Speed, DWORD Counter);
typedef DWORD (__stdcall *TStartDriver) ();
typedef DWORD (__stdcall *TStopDriver) ();

// --- Konstanten ---------------------------------------------------------------

const DWORD ftiAus    = 0;
const DWORD ftiEin    = 1;
const DWORD ftiLinks  = 1;
const DWORD ftiRechts = 2;

const DWORD ftiFehler = 0x0001FFFF;

// --- Funktionen ----------------------------------------------------------------

TOpenInterface   umOpenInterface;
TCloseInterface  umCloseInterface;
TVersion         umGetVersion;
TGetAnalogDirect umGetAnalogDirect;
TGetInput        umGetInput;
TSetLamp         umSetLamp;
TSetMotor        umSetMotor;
TSetMotorEx      umSetMotorEx;
TSetMotors       umSetMotors;
TSetMotorsEx     umSetMotorsEx;
TRobMotors       umRobMotors;
TRobMotor        umRobMotor;
TStartDriver     umStartDriver;
TStopDriver      umStopDriver;

// --- LadeRoutine LoadFish ------------------------------------------------------

BOOLEAN LoadFish(void)
{
  umFishLib = LoadLibrary("umFish30.DLL");
	if(!umFishLib) return FALSE;

	umOpenInterface   = (TOpenInterface)  GetProcAddress(umFishLib, "umOpenInterface");
	umCloseInterface  = (TCloseInterface) GetProcAddress(umFishLib, "umCloseInterface");
	umGetVersion      = (TVersion)        GetProcAddress(umFishLib, "umGetVersion");
  umGetAnalogDirect = (TGetAnalogDirect)GetProcAddress(umFishLib, "umGetAnalogDirect");
	umGetInput        = (TGetInput)       GetProcAddress(umFishLib, "umGetInput");
	umSetLamp         = (TSetLamp)        GetProcAddress(umFishLib, "umSetLamp");
	umSetMotor        = (TSetMotor)       GetProcAddress(umFishLib, "umSetMotor");
	umSetMotorEx      = (TSetMotorEx)     GetProcAddress(umFishLib, "umSetMotorEx");
	umSetMotors       = (TSetMotors)      GetProcAddress(umFishLib, "umSetMotors");
 	umSetMotorsEx     = (TSetMotorsEx)    GetProcAddress(umFishLib, "umSetMotorsEx");
	umRobMotors       = (TRobMotors)      GetProcAddress(umFishLib, "umRobMotors");
	umRobMotor        = (TRobMotor)       GetProcAddress(umFishLib, "umRobMotor");

	umStartDriver     = (TStartDriver)    GetProcAddress(umFishLib, "umStartDriver");
	umStopDriver      = (TStopDriver)     GetProcAddress(umFishLib, "umStopDriver");
	return TRUE;
}

// --- UnloadRoutine FreeFish ----------------------------------------------------

void FreeFish(void)
{
	FreeLibrary(umFishLib);
	umFishLib = NULL;
	return;
}


#endif
